@@ -1,12 +1,12 @@
 #!/usr/bin/env ruby
 $KCODE= 'e'
 #
-# posttdiary-ex: update tDiary via e-mail. $Revision: 1.2 $
+# posttdiary-ex: update tDiary via e-mail. $Revision: 1.4 $
 #
 # Copyright (C) 2002, All right reserved by TADA Tadashi <sho@spc.gr.jp>
 # You can redistribute it and/or modify it under GPL2.
 #
-# 2005.3.17: v.1.54: Modified to posttdiary-ex.rb by K.Sakurai (http://ks.nwr.jp)
+# 2005.7.18: v.1.58: Modified by K.Sakurai (http://ks.nwr.jp)
 #  Acknowledgements:
 #   * Based on posttdiary.rb v1.2 by TADA.
 #   * Some codes partially imported from Enikki Plugin Ex. : 
@@ -21,7 +21,7 @@ $KCODE= 'e'
 def usage( detailed_help )
 	# (if "!" is at the head of the line, it is to be shown only when detailed_help == true (-h option) )
 	text = <<-TEXT
-		#{File::basename __FILE__}: update tDiary via e-mail (v1.54).
+		#{File::basename __FILE__}: update tDiary via e-mail (v1.58).
 		usage: ruby posttdiary-ex.rb [options (without -d)] <url> <user> <passwd>
 		       ruby posttdiary-ex.rb [options (with -d)]
 		arguments:
@@ -95,6 +95,13 @@ def usage( detailed_help )
 !		  --preserve-local-images,   -P:
 !		          Do not delete local image files.
 !		          Effective only when --remote-mode is enabled.
+!		  --upload-only,     -U:
+!		          Upload the attached images to server, but do not update the diary.
+!		          Also possible by adding "_UPLONLY#" to mail body.
+!		  --group-id,        -G: specify the group name (or GID) of the image file.
+!		          Also makes the file group writable (chmod 664).
+!		          ex1. -G www
+!		          ex2. -G 67
 !		  --class-name,      -n class_name:
 !		          Class name for each photo (default: photo)
 !		          Invalid when --use-image-ex or --wiki-style option is enabled.
@@ -167,9 +174,9 @@ def TDiaryError( msg )
 end
 
 def load_cgi_conf
-	raise TDiaryError, 'posttdiary: No @data_path variable.' unless @data_path
+	raise TDiaryError, 'posttdiary-ex: No @data_path variable.' unless @data_path
 	@data_path = add_delimiter( @data_path )
-	raise TDiaryError, 'posttdiary: Do not set @data_path as same as tDiary system directory.' if @data_path == @tdiary_dirname
+	raise TDiaryError, 'posttdiary-ex: Do not set @data_path as same as tDiary system directory.' if @data_path == @tdiary_dirname
 	
 	variables = [:author_name, :author_mail, :index_page, :hour_offset]
 	begin
@@ -204,7 +211,7 @@ def read_tdiary_conf( dfname )
 	true;
 
 	rescue IOError, Errno::ENOENT
-	raise 'posttdiary: failed to read tdiary configuration file'
+	raise 'posttdiary-ex: failed to read tdiary configuration file'
 end
 
 def check_local_images( date, path )
@@ -335,7 +342,7 @@ def read_exif_comment( fullpath_imgname )
 	v
 end
 
-def make_thumbnail( idir, iname , newsize )
+def make_thumbnail( idir, iname , newsize , gid )
 	org_full = idir + iname
 	tb_name = "s" + iname
 	tb_full = idir + tb_name
@@ -351,6 +358,12 @@ def make_thumbnail( idir, iname , newsize )
 		system( "#{@convertpath} -size #{newsize}\\\> #{org_full} -geometry #{newsize}\\\> #{tb_full}" )
 	end
 	if FileTest::exist?( tb_full )
+		if gid then
+			require 'shell'
+			sh = Shell.new
+			sh.chown( nil , gid , tb_full )
+			sh.chmod( 00664 , tb_full )
+		end
 		tb_name
 	else
 		iname
@@ -387,7 +400,7 @@ def add_delimiter( orgpath )
 	newpath
 end
 
-def make_image_body( imgdata , imgname , remotedir , now , image_boundary)
+def make_image_body( imgdata , imgname , remotedir , now , image_boundary, protection_key )
 	fname = ""
 	extension = ""
 	image_body = ""
@@ -408,6 +421,14 @@ image_body.concat <<END
 content-disposition: form-data; name="plugin_image_dir"\r
 \r
 #{add_delimiter(remotedir)}\r
+END
+	end
+	if protection_key and protection_key.length > 0 then
+image_body.concat <<END
+--#{image_boundary}\r
+content-disposition: form-data; name="csrf_protection_key"\r
+\r
+#{protection_key}\r
 END
 	end
 
@@ -469,16 +490,17 @@ def check_remote_images( http, cgi, user, pass, now )
 	[maxnum, available_list]
 end
 
-def post_image( http, cgi, user, pass, image_dir , imgname, remote_image_dir, now)
+def post_image( http, cgi, user, pass, image_dir , imgname, remote_image_dir, now, protection_key, refurl )
 	auth = ["#{user}:#{pass}"].pack( 'm' ).strip
 	image_boundary = "PosttdiaryMainBoundary"
 	image_data = ( File.open( image_dir + imgname ) { |f| f.read } )
-	image_body = make_image_body(image_data, imgname, remote_image_dir, now , image_boundary) if image_data
+	image_body = make_image_body(image_data, imgname, remote_image_dir, now , image_boundary, protection_key ) if image_data
 	if image_body then
 		image_header = {
 		    'Authorization' => "Basic #{auth}",
 		    'Content-Length' => image_body.length.to_s,
 		    'Content-Type' => "multipart/form-data; boundary=#{image_boundary}",
+		    'Referer' => refurl,
 		}
 		response, = http.post( cgi, image_body, image_header )
 		raise "posttdiary-ex: failed to upload image (#{imgname}) to remote server" if response.code.to_i < 200 or response.code.to_i > 202
@@ -591,7 +613,9 @@ begin
 	remote_image_dir = nil
 	remote_yearly_dir = false
 	preserve_local_images = false
+	upload_only = false
 	class_name = 'photo'
+	group_id = nil
 	add_div_imgnum = 2
 	add_div_imgnum_specified = nil
 	threshold_size = nil
@@ -628,6 +652,8 @@ begin
 		['--remote-image-path', '-D', GetoptLong::REQUIRED_ARGUMENT],
 		['--remote-yearly-dir', '-Y', GetoptLong::REQUIRED_ARGUMENT],
 		['--preserve-local-images', '-P', GetoptLong::NO_ARGUMENT],
+		['--upload-only', '-U', GetoptLong::NO_ARGUMENT],
+		['--group-id', '-G', GetoptLong::REQUIRED_ARGUMENT],
 		['--class-name', '-n', GetoptLong::REQUIRED_ARGUMENT],
 		['--add-div', '-v', GetoptLong::REQUIRED_ARGUMENT],
 		['--threshold-size', '-z', GetoptLong::REQUIRED_ARGUMENT],
@@ -679,6 +705,17 @@ begin
 				remote_yearly_dir = (arg =~ /[1yt]/i)
 			when '--preserve-local-images'
 				preserve_local_images = true
+			when '--upload-only'
+				upload_only = true
+				filter_mode = true
+			when '--group-id'
+				if arg =~ /\D/ then
+					require 'etc'
+					group_id = Etc.getgrnam( arg )['gid']
+				else
+					group_id = arg.to_i
+				end
+				group_id = nil if group_id <= 0 or group_id > 65535
 			when '--add-div'
 				add_div_imgnum_specified = arg.to_i
 			when '--threshold-size'
@@ -756,10 +793,13 @@ begin
 		if wiki_style then
 			image_format = '{{image $0,"$4"}}'
 			image_format_with_thumbnail = image_format
-			add_div_imgnum = 0
 		end
 	end
-	add_div_imgnum = add_div_imgnum_specified if add_div_imgnum_specified
+	if wiki_style then
+		add_div_imgnum = 0
+	else
+		add_div_imgnum = add_div_imgnum_specified if add_div_imgnum_specified
+	end
 	@convertpath = convertpath_specified 	if convertpath_specified
 	@convertpath = add_delimiter( @convertpath ) + "convert" if test( ?d , @convertpath )
 	@magickpath = $1 if @convertpath =~ /(.*[\/\\])[^\/\\]+$/
@@ -798,7 +838,7 @@ begin
 		user = $1 unless user
 		pass = $2 unless pass
 	end
-	raise "posttdiary: please specify the username for your tdiary system." unless user or filter_mode
+	raise "posttdiary-ex: please specify the username for your tdiary system." unless user or filter_mode
 	if tmpimglist.length > 0 and ( !image_dir or !image_url ) then
 		raise "posttdiary-ex: please specify image-path (-i) and/or image-url (-u)"
 	end
@@ -814,6 +854,9 @@ begin
 			tmp = Time::local( $1.to_i, $2.to_i, $3.to_i );
 		end
 	end
+	if @body.gsub!( /^\_up[ld]+only\#/i , '' ) then
+		upload_only = true
+	end
 	if tmp >= now + date_margin * 24 * 3600 then
 #		raise "posttdiary-ex: invalid future date"
 #		# use current date (now) instead of specified date(tmp)..
@@ -864,8 +907,12 @@ begin
 		exif_comment[image_name] = (read_exif ? read_exif_comment(image_dir + image_name) : "" )
 		image_orgname[image_name] = orglist[i]
 		change_image_size( image_dir + image_name , image_geometry ) if image_geometry
+		if group_id then
+			sh.chown( nil , group_id , image_dir + image_name )
+			sh.chmod( 00664 , image_dir + image_name )
+		end
 		thumbnail_name[image_name] = ""
-		thumbnail_name[image_name] = make_thumbnail( image_dir, image_name , thumbnail_size ) if thumbnail_size and check_image_size( image_dir + image_name, threshold_size)
+		thumbnail_name[image_name] = make_thumbnail( image_dir, image_name , thumbnail_size , group_id ) if thumbnail_size and check_image_size( image_dir + image_name, threshold_size)
 		@image_name = [] unless @image_name
 		@image_name << image_name
 	end
@@ -934,9 +981,11 @@ begin
 		title = subject
 	end
 
+	if upload_only then
+		exit 0
+	end
 	require 'cgi'
 	require 'nkf'
-
 	if filter_mode then
 		data = title + "\n";
 		data << @body + "\n";
@@ -954,18 +1003,26 @@ begin
 		data << "&year=#{topic_year}"
 		data << "&month=#{topic_month}"
 		data << "&day=#{topic_date}"
+		auth = ["#{user}:#{pass}"].pack( 'm' ).strip
 		Net::HTTP.start( host, port ) do |http|
+			protection_key = nil
+			res, = http.get( cgi,
+	                               'Authorization' => "Basic #{auth}",
+	                               'Referer' => url )
+			if %r|<input type="hidden" name="csrf_protection_key" value="([^"]+)">| =~ res.body then
+				protection_key = $1
+				data << "&csrf_protection_key=#{CGI::escape( CGI::unescapeHTML( protection_key ) )}"
+			end
 			if remote_mode and @image_name then
 				for i in 0 .. (@image_name.length - 1)
 					imagename = @image_name[i]
 					thumbnailname = thumbnail_name[imagename]
-					post_image( http, cgi, user, pass, image_dir, imagename, remote_image_dir, now)
+					post_image( http, cgi, user, pass, image_dir, imagename, remote_image_dir, now, protection_key, url )
 					File.delete( image_dir + imagename ) if !preserve_local_images
 					File.delete( image_dir + thumbnailname ) if !preserve_local_images and test( ?f , image_dir + thumbnailname )
 				end
 			end
-			auth = ["#{user}:#{pass}"].pack( 'm' ).strip
-			response, = http.post( cgi, data, 'Authorization' => "Basic #{auth}" )
+			response, = http.post( cgi, data, 'Authorization' => "Basic #{auth}", 'Referer' => url )
 		end
 	end
 
