@@ -1,10 +1,11 @@
-# amazon.rb $Revision: 1.26 $
+# amazon.rb $Revision: 1.27.2.4 $
 #
 # See document in language resource file: en/amazon.rb
 #
 # ɥȤja/amazon.rb򸫤Ƥ
 #
-# Copyright (C) 2002 by HAL99 <hal99@mtj.biglobe.ne.jp>
+# Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
+# You can redistribute it and/or modify it under GPL2.
 #
 # Original: HAL99 <hal99@mtj.biglobe.ne.jp>
 # Modified: by TADA Tadashi<sho@spc.gr.jp>,
@@ -39,7 +40,7 @@ def get_amazon( asin )
 	end
 
 	item_url = nil
-	item_name = nil
+	item_name = asin
 	img_url = nil
 	img_name = nil
 	img_height = nil
@@ -47,6 +48,7 @@ def get_amazon( asin )
 
 	timeout( limittime ) do
 		item_url = "#{@amazon_url}/#{asin}/"
+		item_url += "?val=authorized" if @conf['amazon.over18']
 
 		begin
 			if %r|http://([^:/]*):?(\d*)(/.*)| =~ item_url then
@@ -79,11 +81,9 @@ def get_amazon( asin )
 				end
 			end
 		rescue Net::ProtoRetriableError => err
-			$stderr.puts "1 #$!"
 			item_url = err.response['location']
 			retry
 		rescue
-			$stderr.puts "2 #$!: #{item_url}"
 			raise 'getting item was failed'
 		end
 	end
@@ -119,10 +119,10 @@ def get_amazon_image( position, asin, comment )
 			end
 		end
 		if @conf['amazon.imgsize'] == 1 then
-			item[2].gsub!(/MZZZZZZZ/, 'TZZZZZZZ')
+			item[2].gsub!(/[ML]ZZZZZZZ/, 'TZZZZZZZ')
 		end
 		if @conf['amazon.imgsize'] == 2 then
-			item[2].gsub!(/MZZZZZZZ/, 'THUMBZZZ')
+			item[2].gsub!(/[ML]ZZZZZZZ/, 'THUMBZZZ')
 		end
 		r = ""
 		r << %Q[<a href="#{item[0].strip}/ref=nosim/">]
@@ -132,15 +132,14 @@ def get_amazon_image( position, asin, comment )
 				r << %Q[width="#{item[4].strip}" ] if item[4]
 				r << %Q[height="#{item[5].strip}" ] if item[5]
 			end
-			r << %Q[alt="#{item[1].strip}">]
+			r << %Q[alt="#{item[1].strip}" title="#{item[1].strip}">]
 		end
 		if !@conf['amazon.hidename']
 			r << item[1].strip if position == "amazon"
 		end
 		r << %Q[</a>]
-	rescue
-		$stderr.puts "3 #$!"
-		asin
+	rescue NameError, StandardError
+		%Q[<a href="#{item[0].strip}/ref=nosim/">#{asin}</a>]
 	end
 end
 
@@ -173,6 +172,7 @@ def amazon_conf_proc
 			@conf['amazon.imgsize'] = @cgi.params['amazon.imgsize'][0].to_i
 			@conf['amazon.hidename'] = (@cgi.params['amazon.hidename'][0] == 'true')
 			@conf['amazon.nodefault'] = (@cgi.params['amazon.nodefault'][0] == 'true')
+			@conf['amazon.over18'] = (@cgi.params['amazon.over18'][0] == 'true')
 			if @cgi.params['amazon.clearcache'][0] == 'true' then
 				Dir["#{@cache_path}/amazon/*"].each do |cache|
 					File::delete( cache.untaint )
@@ -203,6 +203,8 @@ def amazon_conf_proc
 				<option value="true"#{if @conf['amazon.nodefault'] then " selected" end}>#{@amazon_label_usetitle}</option>
 				<option value="false"#{if not @conf['amazon.nodefault'] then " selected" end}>#{@amazon_label_usedefault}</option>
 			</select></p>
+			<h3>#{@amazon_label_over18}</h3>
+			<p><input type="checkbox" name="amazon.over18" value="true"#{@conf['amazon.over18'] ? " checked" : ""}>#{@amazon_label_over18_desc}</input></p>
 			<h3>#{@amazon_label_clearcache}</h3>
 			<p><input type="checkbox" name="amazon.clearcache" value="true">#{@amazon_label_clearcache_desc}</input></p>
 		HTML
