@@ -1,5 +1,5 @@
 =begin
-= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.38 2004/06/12 10:45:28 zunda Exp $-))
+= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.38.2.1 2005/07/20 08:25:01 tadatadashi Exp $-))
 
 == 
 ƥʤΥ󥯡󥸥θ̤̾Υ󥯸βˤ
@@ -1212,7 +1212,7 @@ class DispRef2SetupIF
 		end
 
 		# update cache
-		if not @setup.secure then
+		if @mode == 'saveconf' and not @setup.secure then
 			if not @setup['no_cache'] then
 				unless @cache then
 					@need_cache_update = true
@@ -1253,7 +1253,7 @@ class DispRef2SetupIF
 			r << sprintf( Disp_referrer2_scanned_urls, @scanned_url ) if @scanned_url
 			r << sprintf( Disp_referrer2_updated_urls, @updated_url ) if @updated_url
 			r << sprintf( Disp_referrer2_cache_info, DispRef2String::bytes( @cache.size ), DispRef2String::comma( @cache.entries ) )
-			r << sprintf( Disp_referrer2_update_info, "#{@conf.update}?conf=referer", "#{@conf.update}?conf=disp_referrer2;dr2.cache.update=force;dr2.current_mode=#{@current_mode}" )
+			r << sprintf( Disp_referrer2_update_info, "#{@conf.update}?conf=referer" )
 		end
 		r << "<p>\n"
 		case @current_mode
