@@ -1,5 +1,8 @@
 #
-# English resource of amazon plugin $Revision: 1.3 $
+# Japanese resource of amazon plugin $Revision: 1.3.2.5 $
+#
+# Copyright (C) 2002 HAL99 <hal99@mtj.biglobe.ne.jp>
+# You can redistribute it and/or modify it under GPL2.
 #
 
 #
@@ -50,8 +53,8 @@
 #
 
 @amazon_url = 'http://www.amazon.co.jp/exec/obidos/ASIN'
-@amazon_item_name = /^Amazon.co.jp (.*)<.*$/
-@amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ.jpg))".*?>)|i
+@amazon_item_name = /^Amazon.co.jp[:] *(.*): .*$/
+@amazon_item_image = %r|(<img src="(http://images-jp\.amazon\.com/images/P/(.*MZZZZZZZ_?.jpg))".*?>)|i
 @amazon_label_conf ='Amazonץ饰'
 @amazon_label_aid = 'AmazonIDλ'
 @amazon_label_imgsize = 'ɽ륤᡼Υ'
