@@ -1,5 +1,5 @@
 =begin
-= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.11 2004/09/15 02:21:06 mput Exp $-))
+= Υ󥯸⤦äȤץ饰((-$Id: disp_referrer.rb,v 1.11.2.1 2005/07/20 08:25:02 tadatadashi Exp $-))
 ܸ꥽
 
 == 
@@ -230,8 +230,8 @@ Disp_referrer2_cache_info = <<'_END'.taint
 _END
 Disp_referrer2_update_info = <<'_END'.taint
 <p>
-	<a href="%1$s">󥯸</a>פѹθˤ
-	<a href="%2$s">åι</a>ɬפ⤷ޤ
+	<a href="%1$s">󥯸</a>פѹθˤ⡢
+	åιɬפ⤷ޤ
 </p>
 _END
 Disp_referrer2_move_to_refererlist = <<'_END'.taint
