@@ -1,4 +1,4 @@
-# tb-send.rb $Revision: 1.14 $
+# tb-send.rb $Revision: 1.15.2.2 $
 #
 # Copyright (c) 2003 Junichiro Kita <kita@kitaj.no-ip.com>
 # You can distribute this file under the GPL.
@@ -12,17 +12,23 @@ add_edit_proc do |date|
 	unless @conf['tb.no_section'] then
 		section_titles = ''
 	 	idx = 1
+		selected = false
 		diary = @diaries[@date.strftime('%Y%m%d')]
 		if diary then
 			diary.each_section do |t|
 				anc = 'p%02d' % idx
-				selected = (section == anc ) ? ' selected' : ''
-				section_titles << %[<option value="#{anc}"#{selected}>#{CGI::escapeHTML( apply_plugin( t.subtitle_to_html, true ) ).chomp}</option>\n\t\t\t]
+				if section == anc then
+					focus = ' selected'
+					selected = true
+				else
+					focus = ''
+				end
+				section_titles << %[<option value="#{anc}"#{focus}>#{CGI::escapeHTML( apply_plugin( t.subtitle_to_html, true ) ).chomp}</option>\n\t\t\t]
 				idx += 1
 			end
 		end
 		anc = 'p%02d' % idx
-		section_titles << %[<option value="#{anc}"#{(section == anc ) ? ' selected' : ''}>#{@tb_send_label_current_section}</option>]
+		section_titles << %[<option value="#{anc}"#{selected ? '' : ' selected'}>#{@tb_send_label_current_section}</option>]
 	
 		select_sections = <<-FROM
 			<div class="field">
@@ -38,7 +44,7 @@ add_edit_proc do |date|
 		<h3 class="subtitle">TrackBack</h3>
 		<div class="trackback">
 			<div class="field title">
-			#{@tb_send_label_url}: <textarea tabindex="500" style="height: 1em;" name="plugin_tb_url" cols="40" rows="1">#{CGI::escapeHTML( url )}</textarea>
+			#{@tb_send_label_url}: <textarea tabindex="500" style="height: 2em;" name="plugin_tb_url" cols="40" rows="1">#{CGI::escapeHTML( url )}</textarea>
 			</div>
 			#{select_sections}
 			<div class="textarea">
@@ -53,7 +59,7 @@ add_update_proc do
 end
 
 def tb_send_trackback
-	urls = @cgi.params['plugin_tb_url'][0] || ''
+	urls = (@cgi.params['plugin_tb_url'][0] || '').split
 	title = @cgi.params['title'][0]
 	excerpt = @cgi.params['plugin_tb_excerpt'][0]
 	section = @cgi.params['plugin_tb_section'][0]
@@ -91,7 +97,7 @@ def tb_send_trackback
 	my_url.gsub!( %r|/\./|, '/' )
  
 	require 'net/http'
-	urls.split.each do |url|
+	urls.each do |url|
 		trackback = "url=#{CGI::escape(my_url)}"
 		trackback << "&charset=#{@tb_send_ping_charset}"
 		trackback << "&title=#{CGI::escape( @conf.to_native( title ) )}" unless title.empty?
@@ -107,7 +113,6 @@ def tb_send_trackback
 				Net::HTTP.start( host.untaint, port.to_i ) do |http|
 					response, = http.post( request, trackback,
 						"Content-Type" => 'application/x-www-form-urlencoded')
-					
 					error, = response.body.scan(%r|<error>(\d)</error>|)[0]
 					if error == '1'
 						reason, = response.body.scan(%r|<message>(.*)</message>|m)[0]
@@ -117,6 +122,8 @@ def tb_send_trackback
 			rescue
 				raise TDiaryTrackBackError.new( "when sending TrackBack Ping: #{$!.message}" ) if urls.length == 1
 			end
+		else
+			raise TDiaryTrackBackError.new( "unknown URL: #{url}" ) if urls.length == 1
 		end
 	end
 end
