@@ -1,5 +1,8 @@
 #
-# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.28 $
+# defaultio.rb: tDiary IO class for tDiary 2.x format. $Revision: 1.28.2.2 $
+#
+# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# You can redistribute it and/or modify it under GPL2.
 #
 module TDiary
 	TDIARY_MAGIC_MAJOR = 'TDIARY2'
@@ -7,7 +10,7 @@ module TDiary
 	TDIARY_MAGIC = "#{TDIARY_MAGIC_MAJOR}.#{TDIARY_MAGIC_MINOR}"
 
 	def TDiary::parse_tdiary( data )
-		header, body = data.split( /\n\n/, 2 )
+		header, body = data.split( /\r?\n\r?\n/, 2 )
 		if header and body
 			body.gsub!( /^\./, '' )
 			headers = {}
@@ -28,7 +31,7 @@ module TDiary
 		def restore_comment( file, diaries )
 			begin
 				File::open( file, 'r' ) do |fh|
-					while l = fh.gets( "\n.\n" )
+					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						next unless body
 						comment = Comment::new(
@@ -71,7 +74,7 @@ module TDiary
 		def restore_referer( file, diaries )
 			begin
 				File::open( file, 'r' ) do |fh|
-					while l = fh.gets( "\n.\n" )
+					fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 						headers, body = TDiary::parse_tdiary( l )
 						next unless body
 						body.each do |r|
@@ -186,7 +189,7 @@ module TDiary
 			end
 
 			# read and parse diary
-			while l = fh.gets( "\n.\n" )
+			fh.read.split( /\r?\n\.\r?\n/ ).each do |l|
 				begin
 					headers, body = TDiary::parse_tdiary( l )
 					style = headers['Format'] || 'tDiary'
