@@ -1,6 +1,9 @@
 #
 # tDiary language setup: Japanese(ja)
 #
+# Copyright (C) 2001-2005, TADA Tadashi <sho@spc.gr.jp>
+# You can redistribute it and/or modify it under GPL2.
+#
 
 $KCODE = 'e'
 
@@ -18,29 +21,23 @@ end
 
 require 'nkf'
 begin
+	raise LoadError if defined?( NKF::UTF8 )
 	require 'uconv'
 	eval( <<-TOPLEVEL_CLASS, TOPLEVEL_BINDING )
 		def Uconv.unknown_unicode_handler( unicode )
 			if unicode == 0xff5e
-				"`"
+				""
 			else
 				raise Uconv::Error
 			end
 		end
 	TOPLEVEL_CLASS
 
-	@reg_char_utf8 = /&#[0-9]+;/
 	def to_native( str )
-		if @reg_char_utf8 =~ str then
-			str.gsub!( @reg_char_utf8 ) do |v|
-				Uconv.u8toeuc( [$1.to_i].pack( "U" ) )
-			end
-		else
-			begin
-				str = Uconv.u8toeuc( str )
-			rescue Uconv::Error
-				str = NKF::nkf( '-m0 -e', str )
-			end
+		begin
+			str = Uconv.u8toeuc( str )
+		rescue Uconv::Error
+			str = NKF::nkf( '-m0 -e', str )
 		end
 		str
 	end
